@@ -136,12 +136,23 @@ class Role(BaseModel):
     """"
     角色表
     """
+    status_choices = (
+        ("system", "系统预设"),
+        ("custom", "自定义")
+    )
     name = models.CharField(max_length=32, verbose_name="角色名称")
     desc = models.CharField(max_length=255, null=True, blank=True, verbose_name="角色描述")
     organization_id = models.IntegerField(verbose_name="组织id")
     is_deleted = models.BooleanField(default=False, verbose_name="是否被删除，默认没有被删除")
     is_enabled = models.BooleanField(default=True, verbose_name="是否被启用，默认被启用")
     is_edited = models.BooleanField(default=True, verbose_name="是否可以被删除，编辑")
+    creator_id = models.IntegerField(null=True, verbose_name="角色创建人ID")
+    role_type = models.CharField(
+        max_length=20,
+        choices=status_choices,
+        default="system",
+        verbose_name="角色类型"
+    )
 
     def __str__(self):
         return self.name
