@@ -39,7 +39,7 @@ if __name__ == '__main__':
     # print(obj.root)
 
     # print(obj.list("sub", 2))
-    print(obj.list("all"))
+    # print(obj.list("all"))
     # print(obj.list("all", department_name="o"))
     # print(obj.create({"name": "前端o99", "parent_id": 2}))
     # print(obj.retrieve(3))
